@@ -67,6 +67,22 @@ _SEQDB = {
     '< CSI B'            : 'Cursor key(normal keypad): down arrow',
     '< CSI C'            : 'Cursor key(normal keypad): right arrow',
     '< CSI D'            : 'Cursor key(normal keypad): left arrow',
+    '< CSI 1;2A'         : 'Cursor key (xterm): Shift + up arrow',
+    '< CSI 1;2B'         : 'Cursor key (xterm): Shift + down arrow',
+    '< CSI 1;2C'         : 'Cursor key (xterm): Shift + right arrow',
+    '< CSI 1;2D'         : 'Cursor key (xterm): Shift + left arrow',
+    '< CSI 1;5A'         : 'Cursor key (xterm): Ctrl + up arrow',
+    '< CSI 1;5B'         : 'Cursor key (xterm): Ctrl + down arrow',
+    '< CSI 1;5C'         : 'Cursor key (xterm): Ctrl + right arrow',
+    '< CSI 1;5D'         : 'Cursor key (xterm): Ctrl + left arrow',
+    '< CSI 1;6A'         : 'Cursor key (xterm): Shift + Ctrl + up arrow',
+    '< CSI 1;6B'         : 'Cursor key (xterm): Shift + Ctrl + down arrow',
+    '< CSI 1;6C'         : 'Cursor key (xterm): Shift + Ctrl + right arrow',
+    '< CSI 1;6D'         : 'Cursor key (xterm): Shift + Ctrl + left arrow',
+    '< ESC O A'          : 'Cursor key(application keypad): up arrow',
+    '< ESC O B'          : 'Cursor key(application keypad): down arrow',
+    '< ESC O C'          : 'Cursor key(application keypad): right arrow',
+    '< ESC O D'          : 'Cursor key(application keypad): left arrow',
     '< CSI [0]M'         : 'xterm normal mouse reporting, following 3 bytes mean (code, row, col)',
     '< CSI M'            : 'urxvt (1015) mouse reporting (code,row,col)',
     '< CSI [3]M'         : 'urxvt (1015) mouse reporting (code=(%s-32),row=%s,col=%s)',
@@ -158,6 +174,10 @@ _SEQDB = {
     '< CSI >83;40003;0c' : 'DA2 Response: could be GNU Screen 4.0.3',
     '< CSI >83;40100;0c' : 'DA2 Response: could be GNU Screen 4.1.0',
     '< CSI >85;95;c'     : 'DA2 Response: could be rxvt-unicode',
+    '< ESC O P'          : 'F1 key (xterm)',
+    '< ESC O Q'          : 'F2 key (xterm)',
+    '< ESC O R'          : 'F3 key (xterm)',
+    '< ESC O S'          : 'F4 key (xterm)',
     '< CSI 15~'          : 'F5 key (xterm)',
     '< CSI 17~'          : 'F6 key (xterm)',
     '< CSI 18~'          : 'F7 key (xterm)',
@@ -166,6 +186,42 @@ _SEQDB = {
     '< CSI 21~'          : 'F10 key (xterm)',
     '< CSI 23~'          : 'F11 key (xterm)',
     '< CSI 24~'          : 'F12 key (xterm)',
+    '< CSI 1;2P'         : 'Shift + F1 key (xterm)',
+    '< CSI 1;2Q'         : 'Shift + F2 key (xterm)',
+    '< CSI 1;2R'         : 'Shift + F3 key (xterm)',
+    '< CSI 1;2S'         : 'Shift + F4 key (xterm)',
+    '< CSI 15;2~'        : 'F5 key (xterm)',
+    '< CSI 17;2~'        : 'F6 key (xterm)',
+    '< CSI 18;2~'        : 'F7 key (xterm)',
+    '< CSI 19;2~'        : 'F8 key (xterm)',
+    '< CSI 20;2~'        : 'F9 key (xterm)',
+    '< CSI 21;2~'        : 'F10 key (xterm)',
+    '< CSI 23;2~'        : 'F11 key (xterm)',
+    '< CSI 24;2~'        : 'F12 key (xterm)',
+    '< CSI 1;5P'         : 'Ctrl + F1 key (xterm)',
+    '< CSI 1;5Q'         : 'Ctrl + F2 key (xterm)',
+    '< CSI 1;5R'         : 'Ctrl + F3 key (xterm)',
+    '< CSI 1;5S'         : 'Ctrl + F4 key (xterm)',
+    '< CSI 15;5~'        : 'Ctrl + F5 key (xterm)',
+    '< CSI 17;5~'        : 'Ctrl + F6 key (xterm)',
+    '< CSI 18;5~'        : 'Ctrl + F7 key (xterm)',
+    '< CSI 19;5~'        : 'Ctrl + F8 key (xterm)',
+    '< CSI 20;5~'        : 'Ctrl + F9 key (xterm)',
+    '< CSI 21;5~'        : 'Ctrl + F10 key (xterm)',
+    '< CSI 23;5~'        : 'Ctrl + F11 key (xterm)',
+    '< CSI 24;5~'        : 'Ctrl + F12 key (xterm)',
+    '< CSI 1;6P'         : 'Shift + Ctrl + F1 key (xterm)',
+    '< CSI 1;6Q'         : 'Shift + Ctrl + F2 key (xterm)',
+    '< CSI 1;6R'         : 'Shift + Ctrl + F3 key (xterm)',
+    '< CSI 1;6S'         : 'Shift + Ctrl + F4 key (xterm)',
+    '< CSI 15;6~'        : 'Shift + Ctrl + F5 key (xterm)',
+    '< CSI 17;6~'        : 'Shift + Ctrl + F6 key (xterm)',
+    '< CSI 18;6~'        : 'Shift + Ctrl + F7 key (xterm)',
+    '< CSI 19;6~'        : 'Shift + Ctrl + F8 key (xterm)',
+    '< CSI 20;6~'        : 'Shift + Ctrl + F9 key (xterm)',
+    '< CSI 21;6~'        : 'Shift + Ctrl + F10 key (xterm)',
+    '< CSI 23;6~'        : 'Shift + Ctrl + F11 key (xterm)',
+    '< CSI 24;6~'        : 'Shift + Ctrl + F12 key (xterm)',
     '< CSI 200~'         : 'Start sequense of bracketed paste',
     '< CSI 201~'         : 'Terminate bracketed paste',
 
